Welcome to tweakwcs documentation!
==================================

``tweakwcs`` is a package that provides core algorithms for computing and
applying corrections to ``WCS`` objects such as to minimize mismatch between
image and reference catalogs. Currently only aligning images with ``FITS WCS``
and ``JWST GWCS`` are supported.

.. moduleauthor:: Mihai Cara <help@stsci.edu>

Content
=======

.. toctree::
   :maxdepth: 2

   source/imalign
   source/correctors
   source/matchutils
   source/wcsimage
   source/linearfit
   source/wcsutils
   source/linalg
   source/LICENSE.rst


Development Notes
=================

.. toctree::
   :maxdepth: 1
   :titlesonly:

   source/CHANGELOG.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
